==> qgis_2.0.1.orig.tar.bz2: qgis-2.0.1/src/gui/qgscredentialdialog.h <==
/***************************************************************************
                          qgscredentialdialog.h  -  description
                             -------------------
    begin                : February 2010
    copyright            : (C) 2010 by Juergen E. Fischer
    email                : jef at norbit dot de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef QGSCREDENTIALDIALOG_H
#define QGSCREDENTIALDIALOG_H

#include <ui_qgscredentialdialog.h>
#include <qgisgui.h>
#include "qgscredentials.h"

#include <QString>


/** \ingroup gui
 * A generic dialog for requesting credentials
 */
class GUI_EXPORT QgsCredentialDialog : public QDialog, public QgsCredentials, private Ui_QgsCredentialDialog
{
    Q_OBJECT
  public:
    QgsCredentialDialog( QWidget *parent = 0, Qt::WFlags fl = QgisGui::ModalDialogFlags );
    ~QgsCredentialDialog();

  signals:
    void credentialsRequested( QString, QString *, QString *, QString, bool * );

  private slots:
    void requestCredentials( QString, QString *, QString *, QString, bool * );

  protected:
    virtual bool request( QString realm, QString &username, QString &password, QString message = QString::null );
};

#endif

==> qgis_2.4.0.orig.tar.bz2: qgis-2.4.0/src/gui/qgscredentialdialog.h <==
/***************************************************************************
                          qgscredentialdialog.h  -  description
                             -------------------
    begin                : February 2010
    copyright            : (C) 2010 by Juergen E. Fischer
    email                : jef at norbit dot de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef QGSCREDENTIALDIALOG_H
#define QGSCREDENTIALDIALOG_H

#include <ui_qgscredentialdialog.h>
#include <qgisgui.h>
#include "qgscredentials.h"

#include <QString>


/** \ingroup gui
 * A generic dialog for requesting credentials
 */
class GUI_EXPORT QgsCredentialDialog : public QDialog, public QgsCredentials, private Ui_QgsCredentialDialog
{
    Q_OBJECT
  public:
    QgsCredentialDialog( QWidget *parent = 0, Qt::WindowFlags fl = QgisGui::ModalDialogFlags );
    ~QgsCredentialDialog();

  signals:
    void credentialsRequested( QString, QString *, QString *, QString, bool * );

  private slots:
    void requestCredentials( QString, QString *, QString *, QString, bool * );

  protected:
    virtual bool request( QString realm, QString &username, QString &password, QString message = QString::null );
};

#endif
